from flask import Flask, session, g, render_template_string
from flask_session import Session
from flask_oidc import OpenIDConnect
from werkzeug.middleware.proxy_fix import ProxyFix
from loguru import logger
import redis
import json
import os

try:
  redis_url = os.environ['REDIS_URL']
  oidc_client_secrets = os.environ['OIDC_CLIENT_SECRETS']
  secret_key = os.environ['SECRET_KEY']
except KeyError as e:
  logger.error(f"Required environment variable not set ({e})")
  raise e

app = Flask(__name__)
app.config.update({
  'SECRET_KEY': secret_key,
  'SESSION_TYPE': 'redis',
  'SESSION_REDIS': redis.from_url(redis_url),
  'OIDC_CLIENT_SECRETS': json.loads(oidc_client_secrets),
  'OIDC_SCOPES': 'openid email',
  'OIDC_USER_INFO_ENABLED': True,
  'SESSION_USE_SIGNER': True,
})
Session(app)
oidc = OpenIDConnect(app)



